#include <string.h>
#include <utilstr.h>


/******************************************************************************
 * getconfent - Get the value of an entry in a configuration file
 *
 * ENT:	filename	- File name in which to look for entry
 *		entryname	- Entry of which to obtain value
 *		buf		- Buffer to store entry value
 *		len		- Maximum length to write into buffer
 *
 * RET:	error status
 */

SWORD_NAMESPACE_START

char getconfent(char *filename, char *entryname, char *buf, int len)
{
	return 0;
}

SWORD_NAMESPACE_END
